/*
 * Copyright (c) 2023–2024 Emma Tebibyte <emma@tebibyte.media>
 * SPDX-License-Identifier: AGPL-3.0-or-later
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see https://www.gnu.org/licenses/.
 */

use std::{
	cmp::Ordering,
	env::args,
	io::stdin,
	process::ExitCode,
};

extern crate sysexits;

use sysexits::EX_DATAERR;

fn convert(input: u64) -> (f64, u32) {
	let list: Vec<u32> = vec![3, 6, 9, 12, 15, 18, 21, 24, 27, 30];
	let mut out = (0.0, 0_u32);

	if input < 1000 { return (input as f64, 0); }

	for n in list {
		let c = 10_u64.pow(n);
		match c.cmp(&input) {
			Ordering::Less => {
				out = (input as f64 / c as f64, n);
			},
			Ordering::Equal => {
				return (input as f64 / c as f64, n);
			},
			Ordering::Greater => {},
		};
	}

	out
}

fn main() -> ExitCode {
	let argv = args().collect::<Vec<String>>();
	let mut buf = String::new();
	let _ = stdin().read_line(&mut buf);

	let n: u64 = match buf.trim().parse() {
		Ok(f) => f,
		Err(err) => {
			eprintln!("{}: {}", argv[0], err);
			return ExitCode::from(EX_DATAERR as u8);
		},
	};

	let (number, prefix) = convert(n);

	let si_prefix = format!("{}B", match prefix {
		3 => "K",
		6 => "M",
		9 => "G",
		12 => "T",
		15 => "P",
		18 => "E",
		21 => "Z",
		24 => "Y",
		27 => "R",
		30 => "Q",
		_ => "",
	});

	let out = ((number * 10.0).round() / 10.0).to_string();

	println!("{} {}", out, si_prefix);

	ExitCode::SUCCESS
}
